# CHANGELOG

This is a manually generated log to track changes to the repository for each release. 
Each section should include general headers such as **Implemented enhancements** 
and **Merged pull requests**. All closed issued and bug fixes should be 
represented by the pull requests that fixed them.
Critical items to know are:

 - renamed commands
 - deprecated / removed commands
 - changed defaults
 - backward incompatible changes
 - migration guidance
 - changed behaviour 

The client here will eventually be released as "freegenes" 
and the versions here will coincide with these releases.

## [master](https://github.com/vsoch/freegenes-python/tree/master)
 - Twist API client endpoints (0.0.11)
 - All basic endpoints added, along with client with shell (0.0.1)
 - skeleton of package while server under development (0.0.0)
